@@ -1,6 +1,6 @@
 import typer
 import os
-from .db import delete, draw,fetch
+from .db import delete, draw,fetch,drop
 from .db import insert as insert_data
 
 
@@ -13,6 +13,9 @@ print("-"*20,"\n")
 app = typer.Typer()
 
 
+@app.command()
+def dropall():
+    drop()
 
 @app.command()
 def insert(name,path):
